@@ -21,8 +21,10 @@
 #'
 #' @param return Character vector to specify what to return.
 #' Valid options include:
-#'   - `"plot"`: returns a heatmap plot of signal distribution by hour
-#'   and archetypes (default)
+#'   - `"plot"`: returns a grid showing the distribution of archetypes by
+#'   'breaks' and number of active hours (default)
+#'   - `"plot-dist"`: returns a heatmap plot of signal distribution by hour
+#'   and archetypes
 #'   - `"data"`: returns the raw data with the classified
 #'   archetypes
 #'   - `"table"`: returns a summary table of the archetypes
@@ -42,10 +44,14 @@
 #' @param active_threshold A numeric value specifying the minimum number of
 #'   signals to be greater than in order to qualify as _active_. Defaults to 0.
 #'
-#' @param start_hour A character vector specifying start hours,
-#' e.g. "0900"
-#' @param end_hour A character vector specifying finish hours,
-#' e.g. "1700"
+#' @param start_hour A character vector specifying starting hours, e.g.
+#'   `"0900"`. Note that this currently only supports **hourly** increments. If
+#'   the official hours specifying checking in and 9 AM and checking out at 5
+#'   PM, then `"0900"` should be supplied here.
+#' @param end_hour A character vector specifying starting hours, e.g. `"1700"`.
+#'   Note that this currently only supports **hourly** increments. If the
+#'   official hours specifying checking in and 9 AM and checking out at 5 PM,
+#'   then `"1700"` should be supplied here.
 #'
 #' @param mingroup Numeric value setting the privacy threshold / minimum group
 #'   size. Defaults to 5.
@@ -112,8 +118,9 @@ workpatterns_classify_bw <- function(data,
   start_hour <- as.numeric(gsub(pattern = "00$", replacement = "", x = start_hour))
   end_hour <- as.numeric(gsub(pattern = "00$", replacement = "", x = end_hour))
 
-  # Calculate hours within working hours
-  d <- (end_hour - start_hour) - 1
+  ## Calculate hours within working hours
+  ## e.g. if `end_hour` value is 17, then the reference slot should be 16
+  d <- (end_hour - 1) - start_hour
 
   # Text replacement only for allowed values
 
@@ -185,8 +192,8 @@ workpatterns_classify_bw <- function(data,
                 summarise(First_signal=min(Start),
                           Last_signal=max(End)),
               by=c("PersonId","Date"))%>%
-    mutate(Day_Span=Last_signal-First_signal,
-           Signals_Break_hours=Day_Span-Signals_Total)
+    mutate(Day_Span = Last_signal - First_signal,
+           Signals_Break_hours = Day_Span - Signals_Total)
 
 
   personas_levels <-
@@ -251,9 +258,15 @@ workpatterns_classify_bw <- function(data,
       # geom_text(aes(label = percent(Freq)), size = 3) +
       labs(title = "Distribution of Signals by Hour",
            subtitle = "Weekly Working Patterns Archetypes") +
-      scale_fill_gradient2(low = "white", high = "red") +
+      scale_fill_continuous(
+        guide="legend",
+        low = "white",
+        high = "#1d627e",
+        breaks = 0:1,
+        name="",
+        labels = c("", "Observed activity")
+        ) +
       wpa::theme_wpa_basic() +
-      ggplot2::theme(legend.position = "none") +
       ggplot2::annotate("text",
                         y = myTable_legends$Personas,
                         x = 26.5,
@@ -270,14 +283,14 @@ workpatterns_classify_bw <- function(data,
                ymin = 0.5,
                ymax = 7.5,
                alpha = .1,
-               fill = "red") +
+               fill = "gray50") +
       ggplot2::annotate("rect",
                xmin = end_hour + 0.5,
                xmax = 24.5,
                ymin = 0.5,
                ymax = 7.5,
                alpha = .1,
-               fill = "red")
+               fill = "gray50")
   }
 
   # Plot area chart over time -----------------------------------------------
@@ -337,6 +350,10 @@ workpatterns_classify_bw <- function(data,
 
     plot_workpatterns_classify_bw(ptn_data_final)
 
+  } else if(return == "plot-dist"){
+
+    return_plot()
+
   } else if(return == "plot-area"){
 
     return_plot_area()
@@ -498,8 +515,8 @@ plot_workpatterns_classify_bw <- function(data){
                                   "13+ hours", ""
                                   )) +
     scale_x_continuous(breaks = 0:4,
-                       labels = c("", "No breaks", "",
-                                  "Breaks", "")) +
+                       labels = c("", "No recurring breaks", "",
+                                  "Take recurring breaks", "")) +
     labs(title = "Distribution of Working Patterns",
          subtitle = "Classification of employee-weeks",
          x = "Flexibility level (breaks)",
