@@ -56,7 +56,7 @@
 #'
 workpatterns_classify_pav <- function(data,
                                       values = "percent",
-                                      signals = "email",
+                                      signals = c("email", "IM"),
                                       start_hour = "0900",
                                       end_hour = "1700",
                                       return = "plot"){
