@@ -18,6 +18,8 @@
 #' e.g. "`0900"`
 #' @param end_hour A character vector specifying starting hours,
 #' e.g. `"1700"`
+#' @param top number specifying how many top working patterns to display in plot,
+#' e.g. `"10"`
 #' @param return String specifying what to return. This must be one of the
 #'   following strings:
 #'   - `"plot"`
@@ -45,6 +47,7 @@ workpatterns_rank <- function(data,
                               signals = c("email", "IM"),
 							  start_hour = "0900",
                               end_hour = "1700",
+							  top = 10,
                               return = "plot"){
 
   # Make sure data.table knows we know we're using it
@@ -67,6 +70,9 @@ workpatterns_rank <- function(data,
 
   ## Select input variable names
   if("email" %in% signals & "IM" %in% signals){
+  
+    ## Create label for plot subtitle
+	subtitle_signal <- "emails / chats"
 
     ## Create 24 summed `Signals_sent` columns
     signal_cols <-
@@ -87,7 +93,10 @@ workpatterns_rank <- function(data,
 
   } else if(signals == "IM"){
 
-    match_index <- grepl(pattern = "^IMs_sent", x = names(data2))
+	## Create label for plot subtitle
+	subtitle_signal <- "chats"
+		
+	match_index <- grepl(pattern = "^IMs_sent", x = names(data2))
     input_var <- names(data2)[match_index]
     input_var2 <- c("PersonId", "Date", input_var)
 
@@ -100,7 +109,10 @@ workpatterns_rank <- function(data,
 
 
   } else if(signals == "email"){
-
+  
+    ## Create label for plot subtitle
+	subtitle_signal <- "emails"
+	
     match_index <- grepl(pattern = "^Emails_sent", x = names(data2))
     input_var <- names(data2)[match_index]
     input_var2 <- c("PersonId", "Date", input_var)
@@ -143,23 +155,26 @@ workpatterns_rank <- function(data,
       myTable_return %>%
       dplyr::select(patternRank, WeekCount) %>%
       dplyr::mutate(WeekPercentage = WeekCount / sum(WeekCount, na.rm = TRUE),
-                    WeekCount = paste0("n= ", WeekCount, " (", scales::percent(WeekPercentage, accuracy = 0.1), ")")) %>%
-      utils::head(10)
+                    WeekCount = paste0(scales::percent(WeekPercentage, accuracy = 0.1))) %>%
+      utils::head(top)
+	  
+	coverage <- myTable_legends %>% summarize(total=sum(WeekPercentage)) %>% pull(1)  %>% scales::percent(accuracy = 0.1)
 
     myTable_return %>%
       dplyr::select(patternRank, dplyr::starts_with(sig_label_))  %>%
       purrr::set_names(nm = gsub(pattern = sig_label_, replacement = "", x = names(.))) %>%
       purrr::set_names(nm = gsub(pattern = "_.+", replacement = "", x = names(.))) %>%
-      utils::head(10)  %>%
+      utils::head(top)  %>%
       tidyr::gather(Hours, Freq, -patternRank)  %>%
-      ggplot2::ggplot(ggplot2::aes(x = Hours, y = patternRank, fill = Freq)) +
+      ggplot2::ggplot(ggplot2::aes(x = Hours, y = patternRank, fill = Freq )) +
       ggplot2::geom_tile(height=.5) +
-      ggplot2::ylab("Top 10 Activity Patterns") +
-      ggplot2::scale_fill_gradient2(low = "white", high = "#1d627e") +
-      ggplot2::scale_y_reverse(expand = c(0, 0), breaks=seq(1,10)) +
+      ggplot2::ylab(paste("Top", top, "activity patterns")) +
+      #ggplot2::scale_fill_gradient2(low = "white", high = "#1d627e") +
+      ggplot2::scale_y_reverse(expand = c(0, 0), breaks=seq(1,top)) +
       theme_wpa_basic() +
 	  ggplot2::scale_x_discrete(position = "top") +
-      ggplot2::theme(legend.position = "none", axis.line = element_blank(), axis.ticks = element_blank()) +
+      ggplot2::theme(axis.title.x = element_blank(), axis.line = element_blank(), axis.ticks = element_blank()) +
+	  scale_fill_continuous(guide="legend", low = "white", high = "#1d627e", breaks = 0:1, name="", labels = c("", paste("Observed", subtitle_signal, "activity"))) +
       ggplot2::annotate("text",
                y = myTable_legends$patternRank,
                x = 26.5,
@@ -183,7 +198,10 @@ workpatterns_rank <- function(data,
                ymin = 0.5,
                ymax = length(myTable_legends$patternRank) + 0.5,
                alpha = .1,
-               fill = "gray50")
+               fill = "gray50") +
+  labs(title = "Patterns of digital activity",
+       subtitle =paste("Hourly activity based on", subtitle_signal ,"sent over a week"),
+	   caption = paste("Top", top, "patterns represent", coverage, "of workweeks.", extract_date_range(data, return = "text")))
 
   } else if(return == "table"){
 
